Crate kcode_dev_tools_chatend

Crate kcode_dev_tools_chatend 

Chatend projection for Kennedy’s managed development tools.

Structs

FreeformWrite
A validated request to capture one complete source file from a provider.
SourceSnapshot

Enums

ManagedSourceKind

Functions

apply_snapshot
Create or revise the stable Chatend source box represented by a snapshot.
decode_freeform_write
Parse a managed freeform-write call without consulting Chatend.
prepare_freeform_write
Parse a managed freeform-write call and ensure that its source is open.
source_box_id
Find the active stable Chatend box for one managed project.