prepare_freeform_write

Function prepare_freeform_write 

pub fn prepare_freeform_write(
    session: &Session,
    tool_name: &str,
    arguments: &Value,
) -> Result<Option<FreeformWrite>>
Parse a managed freeform-write call and ensure that its source is open.

Unrelated tool names return None without inspecting their arguments.