Chatend projection for Kennedy’s managed development tools.
Structs
- Freeform
Write - A validated request to capture one complete source file from a provider.
- Source
Snapshot
Enums
Functions
- apply_
snapshot - Create or revise the stable Chatend source box represented by a snapshot.
- prepare_
freeform_ write - Parse a managed freeform-write call and ensure that its source is open.
- source_
box_ id - Find the active stable Chatend box for one managed project.